@@ -2,16 +2,21 @@ use strict;
 use warnings;
 
 package Code::TidyAll::Plugin::SortLines::Naturally;
-$Code::TidyAll::Plugin::SortLines::Naturally::VERSION = '0.000002';
+$Code::TidyAll::Plugin::SortLines::Naturally::VERSION = '0.000003';
 use Moo;
 extends 'Code::TidyAll::Plugin';
 
-use Sort::Naturally qw( nsort );
+use Unicode::Collate::Locale ();
+
+has 'locale' => ( is => 'ro', default => 'en_US' );
 
 sub transform_source {
     my ( $self, $source ) = @_;
 
-    return join( "\n", nsort( grep {/\S/} split( /\n/, $source ) ) ) . "\n";
+    my $collator = Unicode::Collate::Locale->new( locale => $self->locale );
+    return
+        join( "\n", $collator->sort( grep {/\S/} split( /\n/, $source ) ) )
+        . "\n";
 }
 
 1;
@@ -22,11 +27,11 @@ sub transform_source {
 
 =head1 NAME
 
-Code::TidyAll::Plugin::SortLines::Naturally - Sort lines of a file using Sort::Naturally
+Code::TidyAll::Plugin::SortLines::Naturally - Sort lines of a file using Unicode::Collate::Locale
 
 =head1 VERSION
 
-version 0.000002
+version 0.000003
 
 =head1 SYNOPSIS
 
@@ -41,6 +46,16 @@ Sorts the lines of a file; whitespace lines are discarded. Useful for files
 containing one entry per line, such as C<.svnignore>, C<.gitignore>, and
 C<.ispell*>.
 
+=head1 CONFIGURATION
+
+=over
+
+=item locale
+
+The locale to use for collation. Defaults to "en_US".
+
+=back
+
 =head1 ACKNOWLEDGEMENTS
 
 This code was essentially pilfered from L<Code::TidyAll::Plugin::SortLines>
@@ -60,5 +75,5 @@ the same terms as the Perl 5 programming language system itself.
 
 __END__
 
-# ABSTRACT: Sort lines of a file using Sort::Naturally
+# ABSTRACT: Sort lines of a file using Unicode::Collate::Locale
 
